==> foundation-2.6.1.tgz: package/PageDoc/PageDoc.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const PageDoc = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.277 12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L19.722 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.09a1.73 1.73 0 001.73-1.73v-2.448h.005V12.5zM29.679 83.294V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707H70.32v66.587H29.679z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M38.663 61.862h-4.124v9.231h4.138c2.893 0 5.052-1.675 5.052-4.623s-2.16-4.608-5.066-4.608zm0 6.796h-1.329v-4.36h1.342c1.495 0 2.214.927 2.214 2.173.001 1.162-.829 2.187-2.227 2.187zm11.295-6.948c-2.851 0-5.052 1.938-5.052 4.775 0 2.837 2.201 4.774 5.052 4.774 2.851 0 5.051-1.938 5.051-4.774.001-2.838-2.2-4.775-5.051-4.775zm0 7.086c-1.343 0-2.214-1.024-2.214-2.311s.872-2.312 2.214-2.312 2.214 1.024 2.214 2.312-.871 2.311-2.214 2.311zm11.31-4.623c.831 0 1.55.623 1.786 1.342l2.408-1.121c-.554-1.273-1.771-2.685-4.194-2.685-2.892 0-5.079 1.924-5.079 4.775 0 2.837 2.187 4.774 5.079 4.774 2.422 0 3.654-1.467 4.194-2.699l-2.408-1.107c-.235.719-.955 1.342-1.786 1.342-1.342 0-2.242-1.024-2.242-2.311s.899-2.31 2.242-2.31z"
  }));
});
PageDoc.displayName = 'PageDoc';
export const PageDocDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/PageDoc/PageDoc.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var PageDoc = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.277 12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L19.722 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.09a1.73 1.73 0 001.73-1.73v-2.448h.005V12.5zM29.679 83.294V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707H70.32v66.587H29.679z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M38.663 61.862h-4.124v9.231h4.138c2.893 0 5.052-1.675 5.052-4.623s-2.16-4.608-5.066-4.608zm0 6.796h-1.329v-4.36h1.342c1.495 0 2.214.927 2.214 2.173.001 1.162-.829 2.187-2.227 2.187zm11.295-6.948c-2.851 0-5.052 1.938-5.052 4.775 0 2.837 2.201 4.774 5.052 4.774 2.851 0 5.051-1.938 5.051-4.774.001-2.838-2.2-4.775-5.051-4.775zm0 7.086c-1.343 0-2.214-1.024-2.214-2.311s.872-2.312 2.214-2.312 2.214 1.024 2.214 2.312-.871 2.311-2.214 2.311zm11.31-4.623c.831 0 1.55.623 1.786 1.342l2.408-1.121c-.554-1.273-1.771-2.685-4.194-2.685-2.892 0-5.079 1.924-5.079 4.775 0 2.837 2.187 4.774 5.079 4.774 2.422 0 3.654-1.467 4.194-2.699l-2.408-1.107c-.235.719-.955 1.342-1.786 1.342-1.342 0-2.242-1.024-2.242-2.311s.899-2.31 2.242-2.31z"
  }));
});
PageDoc.displayName = 'PageDoc';
export var PageDocDimensions = {
  height: 100,
  width: 100
};
